@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for YAP Prolog 6.3.4 and later versions
-%  Last updated on January 21, 2020
+%  Last updated on March 17, 2020
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -639,6 +639,13 @@
 '$lgt_yap_directive_expansion'(module(Module,Exports0), [(:- module(Module,Exports))| Clauses]) :-
 	'$lgt_yap_split_predicate_aliases'(Exports0, Exports, Clauses).
 
+'$lgt_yap_directive_expansion'(reexport([]), []) :-
+	!.
+'$lgt_yap_directive_expansion'(reexport([File| Files]), [(:- use_module(Module, Exports)), (:- export(Exports))| Terms]) :-
+	!,
+	'$lgt_yap_list_of_exports'(File, Module, Exports0),
+	'$lgt_yap_fix_predicate_aliases'(Exports0, Exports),
+	'$lgt_yap_directive_expansion'(reexport(Files), Terms).
 '$lgt_yap_directive_expansion'(reexport(File), [(:- use_module(Module, Exports)), (:- export(Exports))]) :-
 	'$lgt_yap_list_of_exports'(File, Module, Exports0),
 	'$lgt_yap_fix_predicate_aliases'(Exports0, Exports).
@@ -710,6 +717,22 @@
 	'$lgt_compile_predicate_heads'(Head, _, THead, _).
 
 
+'$lgt_yap_list_of_exports'(File, Module, Exports) :-
+	(	logtalk_load_context(directory, Directory)
+	;	logtalk_load_context(file, IncludeFile),
+		file_directory_name(IncludeFile, Directory)
+	),
+	absolute_file_name(File, Path, [file_type(prolog), access(read), file_errors(fail), relative_to(Directory)]),
+	(	module_property(Module, file(Path)),
+		% only succeeds for loaded modules
+		module_property(Module, exports(Exports)) ->
+		true
+	;	object_property(Module, file(Path)),
+		object_property(Module, module),
+		% module compiled as an object
+		object_property(Module, public(Exports))
+	),
+	!.
 '$lgt_yap_list_of_exports'(File, Module, Exports) :-
 	(	absolute_file_name(File, Path, [file_type(prolog), access(read), file_errors(fail)]),
 		file_property(Path, type(regular))
@@ -731,6 +754,7 @@
 	).
 
 '$lgt_yap_read_module_directive'(Stream, Module, Exports) :-
+	% fragile hack as it ignores predicates exported via reexport/1-2 directives
 	read(Stream, FirstTerm),
 	(	FirstTerm  = (:- module(Module, Exports)) ->
 		true
