@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Unit testing automation script
-##   Last updated on January 24, 2020
+##   Last updated on March 1, 2020
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -25,7 +25,7 @@
 # loosely based on a unit test automation script contributed by Parker Jones
 
 print_version() {
-	echo "$(basename "$0") 0.34"
+	echo "$(basename "$0") 1.0"
 	exit 0
 }
 
@@ -76,13 +76,11 @@ coverage_xml_goal="logtalk_load(lgtunit(coverage_report))"
 
 # default argument values
 
+backend=swi
+output='verbose'
 base="$PWD"
 level=""
 results="$base/logtalk_tester_logs"
-backend=swi
-prolog='SWI-Prolog'
-logtalk=swilgt$extension
-logtalk_call="$logtalk -g"
 mode='normal'
 format='default'
 coverage='none'
@@ -101,12 +99,14 @@ else
 	sed="sed"
 fi
 
-run_tests() {
+run_testset() {
 	unit=$(dirname "$1")
 	unit_short=${unit#$prefix}
 	cd "$unit" || exit 1
-	echo '*******************************************************************************'
-	echo "***** Testing $unit_short"
+	if [ "$output" == 'verbose' ] ; then
+		echo "%"
+		echo "% $unit_short"
+	fi
 	if [ -f tester.sh ] ; then
 		if [ $# -eq 0 ] ; then
 			source tester.sh -p $backend
@@ -115,35 +115,52 @@ run_tests() {
 		fi
 		source_exit=$?
 		if [ "$source_exit" -gt 0 ] ; then
-			echo "*****         source tester.sh returned code $source_exit"
-			echo '*******************************************************************************'
+			echo "%         source tester.sh returned code $source_exit"
 			exit 9
 		fi
 	fi
 	name=${unit////__}
+	report_goal="logtalk_load(lgtunit(automation_report)),set_logtalk_flag(test_results_directory,'$results'),set_logtalk_flag(test_unit_name,'$name')"
 	if [ $mode == 'optimal' ] || [ $mode == 'all' ] ; then
-		run_test "$name" "$initialization_goal,$format_goal,$coverage_goal,$flag_goal,$tester_optimal_goal"
+		run_tests "$name" "$initialization_goal,$report_goal,$format_goal,$coverage_goal,$flag_goal,$tester_optimal_goal"
 		tests_exit=$?
-		grep -a 'tests:' "$results/$name.results" | $sed 's/%/***** (opt)  /'
+		mode_prefix="% (opt)   "
 	elif [ $mode == 'normal' ] || [ $mode == 'all' ] ; then
-		run_test "$name" "$initialization_goal,$format_goal,$coverage_goal,$flag_goal,$tester_normal_goal"
+		run_tests "$name" "$initialization_goal,$report_goal,$format_goal,$coverage_goal,$flag_goal,$tester_normal_goal"
 		tests_exit=$?
-		grep -a 'tests:' "$results/$name.results" | $sed 's/%/*****        /'
+		mode_prefix="%         "
 	elif [ $mode == 'debug' ] || [ $mode == 'all' ] ; then
-		run_test "$name" "$initialization_goal,$format_goal,$coverage_goal,$flag_goal,$tester_debug_goal"
+		run_tests "$name" "$initialization_goal,$report_goal,$format_goal,$coverage_goal,$flag_goal,$tester_debug_goal"
 		tests_exit=$?
-		grep -a 'tests:' "$results/$name.results" | $sed 's/%/***** (debug)/'
+		mode_prefix="% (debug) "
 	fi
-	if [ $tests_exit -eq 0 ] ; then
-		grep -a 'completed tests from object' "$results/$name.results" | $sed 's/%/*****        /'
-		grep -a 'out of' "$results/$name.results" | grep -a 'clause coverage' | $sed 's/%/*****        /'
-		grep -a 'no code coverage information collected' "$results/$name.results" | $sed 's/%/*****        /'
-		grep -a '(not applicable)' "$results/$name.results" | $sed 's/(/*****         (/'
+	if [ $tests_exit -eq 0 ] && [ -f "$results/$name.totals" ] && [ "$output" == 'verbose' ] ; then
+		while read -r line ; do
+			echo -n "$mode_prefix"
+			echo -n "$(cut -f 3 <<< "$line")"
+			echo -n ' tests: '
+			echo -n "$(cut -f 4 <<< "$line")"
+			echo -n ' skipped, '
+			echo -n "$(cut -f 5 <<< "$line")"
+			echo -n ' passed, '
+			echo -n "$(cut -f 6 <<< "$line")"
+			echo ' failed'		
+			echo -n '%         completed tests from object '
+			echo "$(cut -f 2 <<< "$line")"
+		done < <(grep '^object' "$results/$name.totals")
+		echo -n '%         clause coverage '
+		echo "$(grep "^coverage" "$results/$name.totals" | cut -f 2)"
+	elif [ $tests_exit -eq 0 ] && [ "$output" == 'verbose' ] ; then
+		grep -a '(not applicable)' "$results/$name.results" | $sed 's/(/%         (/'
 	elif [ $tests_exit -eq 124 ] ; then
-		echo "*****         timeout"
+		if [ "$output" == 'verbose' ] ; then
+			echo "%         timeout"
+		fi
 		echo "LOGTALK_TIMEOUT" >> "$results/$name.errors"
-	else
-		echo "*****         crash"
+	elif [ $tests_exit -ne 0 ] ; then
+		if [ "$output" == 'verbose' ] ; then
+			echo "%         crash"
+		fi
 		echo "LOGTALK_CRASH" >> "$results/$name.errors"
 	fi
 	if [ $coverage == 'xml' ] ; then
@@ -158,7 +175,7 @@ run_tests() {
 	return 0
 }
 
-run_test() {
+run_tests() {
 	name="$1"
 	goal="$2"
 	if [ ${#args[@]} -eq 0 ] ; then
@@ -175,7 +192,10 @@ run_test() {
 		fi
 	fi
 	exit=$?
-	if [ $exit -eq 0 ] && ! grep -q "(not applicable)" "$results/$name.results" && ! grep -q "tests:" "$results/$name.results" && ! grep -q "tests skipped" "$results/$name.results"; then
+	if [ $exit -eq 0 ] && ! grep -q "(not applicable)" "$results/$name.results" && ! grep -q -s "^object" "$results/$name.totals" && ! grep -q "tests skipped" "$results/$name.results"; then
+		if [ "$output" == 'verbose' ] ; then
+			echo "%         broken"
+		fi
 		echo "LOGTALK_BROKEN" >> "$results/$name.errors"
 	fi
 	return $exit
@@ -190,12 +210,13 @@ usage_help()
 	echo "errors, this script returns a non-zero exit code."
 	echo
 	echo "Usage:"
-	echo "  $(basename "$0") [-p prolog] [-m mode] [-f format] [-d results] [-t timeout] [-s prefix] [-c report] [-l level] [-- arguments]"
+	echo "  $(basename "$0") [-o output] [-p prolog] [-m mode] [-f format] [-d results] [-t timeout] [-s prefix] [-c report] [-l level] [-i options] [-g goal] [-- arguments]"
 	echo "  $(basename "$0") -v"
 	echo "  $(basename "$0") -h"
 	echo
 	echo "Optional arguments:"
 	echo "  -v print version of $(basename "$0")"
+	echo "  -o output (valid values are verbose and minimal; default is $output)"
 	echo "  -p backend Prolog compiler (default is $backend)"
 	echo "     (valid values are b, cx, eclipse, gnu, ji, lean, qp, sicstus, swi, swipack, xsb, xsbmt, and yap)"
 	echo "  -m compilation mode (default is $mode)"
@@ -209,16 +230,18 @@ usage_help()
 	echo "     (valid values are none and xml)"
 	echo "  -l directory depth level to look for test sets (default is to recurse into all sub-directories)"
 	echo "     (level 1 means current directory only)"
+	echo "  -i integration script command-line options (no default)"
 	echo "  -g initialization goal (default is $initialization_goal)"
-	echo "  -- arguments to be passed to the integration script used to run the tests (no default)"
+	echo "  -- arguments to be passed to the tests (no default)"
 	echo "  -h help"
 	echo
 }
 
-while getopts "vp:m:f:d:t:s:c:l:g:h" option
+while getopts "vo:p:m:f:d:t:s:c:l:g:i:h" option
 do
 	case $option in
 		v) print_version;;
+		o) o_arg="$OPTARG";;
 		p) p_arg="$OPTARG";;
 		m) m_arg="$OPTARG";;
 		f) f_arg="$OPTARG";;
@@ -227,6 +250,7 @@ do
 		s) s_arg="$OPTARG";;
 		c) c_arg="$OPTARG";;
 		l) l_arg="$OPTARG";;
+		i) i_arg="$OPTARG";;
 		g) g_arg="$OPTARG";;
 		h) usage_help; exit;;
 		*) usage_help; exit;;
@@ -236,41 +260,57 @@ done
 shift $((OPTIND - 1))
 args=("$@")
 
+if [ "$o_arg" == "verbose" ] ; then
+	output='verbose'
+elif [ "$o_arg" == "minimal" ] ; then
+	output='minimal'
+elif [ "$o_arg" != "" ] ; then
+	echo "Error! Unknown output verbosity: $o_arg" >&2
+	usage_help
+	exit 1
+fi
+
+# default backend
+
+prolog='SWI-Prolog'
+logtalk=swilgt$extension
+logtalk_call="$logtalk $i_arg -g"
+
 if [ "$p_arg" == "b" ] || [ "$p_arg" == "b-prolog" ] ; then
 	backend=b
 	prolog='B-Prolog'
 	logtalk=bplgt$extension
-	logtalk_call="$logtalk -g"
+	logtalk_call="$logtalk $i_arg -g"
 elif [ "$p_arg" == "cx" ] || [ "$p_arg" == "cxprolog" ] ; then
 	backend=cx
 	prolog='CxProlog'
 	logtalk=cxlgt$extension
-	logtalk_call="$logtalk --goal"
+	logtalk_call="$logtalk $i_arg --goal"
 elif [ "$p_arg" == "eclipse" ] ; then
 	backend=eclipse
 	prolog='ECLiPSe'
 	logtalk=eclipselgt$extension
-	logtalk_call="$logtalk -e"
+	logtalk_call="$logtalk $i_arg -e"
 elif [ "$p_arg" == "gnu" ] || [ "$p_arg" == "gnu-prolog" ] ; then
 	backend=gnu
 	prolog='GNU Prolog'
 	logtalk=gplgt$extension
-	logtalk_call="$logtalk --query-goal"
+	logtalk_call="$logtalk $i_arg --query-goal"
 elif [ "$p_arg" == "ji" ] || [ "$p_arg" == "jiprolog" ] ; then
 	backend=ji
 	prolog='JIProlog'
 	logtalk=jiplgt$extension
-	logtalk_call="$logtalk -n -g"
+	logtalk_call="$logtalk $i_arg -n -g"
 elif [ "$p_arg" == "lean" ] || [ "$p_arg" == "lean-prolog" ] ; then
 	backend=lean
 	prolog='Lean Prolog'
 	logtalk=lplgt$extension
-	logtalk_call="$logtalk"
+	logtalk_call="$logtalk $i_arg"
 elif [ "$p_arg" == "qp" ] || [ "$p_arg" == "qu-prolog" ] ; then
 	backend=qp
 	prolog='Qu-Prolog'
 	logtalk=qplgt$extension
-	logtalk_call="$logtalk -g"
+	logtalk_call="$logtalk $i_arg -g"
 	versions_goal=$versions_goal_dot
 	tester_optimal_goal=$tester_optimal_goal_dot
 	tester_normal_goal=$tester_normal_goal_dot
@@ -279,7 +319,7 @@ elif [ "$p_arg" == "sicstus" ] || [ "$p_arg" == "sicstus-prolog" ] ; then
 	backend=sicstus
 	prolog='SICStus Prolog'
 	logtalk=sicstuslgt$extension
-	logtalk_call="$logtalk --goal"
+	logtalk_call="$logtalk $i_arg --goal"
 	versions_goal=$versions_goal_dot
 	tester_optimal_goal=$tester_optimal_goal_dot
 	tester_normal_goal=$tester_normal_goal_dot
@@ -288,17 +328,17 @@ elif [ "$p_arg" == "swi" ] || [ "$p_arg" == "swi-prolog" ] ; then
 	backend=swi
 	prolog='SWI-Prolog'
 	logtalk=swilgt$extension
-	logtalk_call="$logtalk -g"
+	logtalk_call="$logtalk $i_arg -g"
 elif [ "$p_arg" == "swipack" ] ; then
 	backend=swipack
 	prolog='SWI-Prolog'
 	logtalk=swipl
-	logtalk_call="$logtalk -g"
+	logtalk_call="$logtalk $i_arg -g"
 elif [ "$p_arg" == "xsb" ] ; then
 	backend=xsb
 	prolog='XSB'
 	logtalk=xsblgt$extension
-	logtalk_call="$logtalk -e"
+	logtalk_call="$logtalk $i_arg -e"
 	versions_goal=$versions_goal_dot
 	tester_optimal_goal=$tester_optimal_goal_dot
 	tester_normal_goal=$tester_normal_goal_dot
@@ -307,7 +347,7 @@ elif [ "$p_arg" == "xsbmt" ] ; then
 	backend=xsbmt
 	prolog='XSB-MT'
 	logtalk=xsbmtlgt$extension
-	logtalk_call="$logtalk -e"
+	logtalk_call="$logtalk $i_arg -e"
 	versions_goal=$versions_goal_dot
 	tester_optimal_goal=$tester_optimal_goal_dot
 	tester_normal_goal=$tester_normal_goal_dot
@@ -316,7 +356,7 @@ elif [ "$p_arg" == "yap" ] ; then
 	backend=yap
 	prolog='YAP'
 	logtalk=yaplgt$extension
-	logtalk_call="$logtalk -g"
+	logtalk_call="$logtalk $i_arg -g"
 elif [ "$p_arg" != "" ] ; then
 	echo "Error! Unsupported backend Prolog compiler: $p_arg" >&2
 	usage_help
@@ -368,11 +408,6 @@ elif [ "$c_arg" != "" ] ; then
 	exit 1
 fi
 
-if [ "$p_arg" == "swipack" ] ; then
-	versions_goal="use_module(library(logtalk)),$versions_goal"
-	format_goal="use_module(library(logtalk)),$format_goal"
-fi
-
 if [ "$d_arg" != "" ] ; then
 	results="$d_arg"
 fi
@@ -399,6 +434,10 @@ if [ "$g_arg" != "" ] ; then
 	initialization_goal="$g_arg"
 fi
 
+if [ "$p_arg" == "swipack" ] ; then
+	initialization_goal="use_module(library(logtalk)),$initialization_goal"
+fi
+
 if [ "$timeout_command" == "" ] ; then
 	echo "Warning! Timeout support not available. The timeout option will be ignored." >&2
 fi
@@ -415,75 +454,107 @@ rm -f "$results"/*.errors
 rm -f "$results"/errors.all
 rm -f "$results"/tester_versions.txt
 
-start_date=$(eval date \"+%Y-%m-%d %H:%M:%S\")
+if [ "$output" == 'verbose' ] ; then
+	start_date=$(eval date \"+%Y-%m-%d %H:%M:%S\")
+	echo "% Batch testing started @ $start_date"
+	$logtalk_call $versions_goal > "$results"/tester_versions.txt 2> /dev/null
+	grep -a "Logtalk version:" "$results"/tester_versions.txt
+	grep -a "Prolog version:" "$results"/tester_versions.txt | $sed "s/Prolog/$prolog/"
+fi
 
-echo '*******************************************************************************'
-echo "***** Batch testing started @ $start_date"
-$logtalk_call $versions_goal > "$results"/tester_versions.txt 2> /dev/null
-grep -a "Logtalk version:" "$results"/tester_versions.txt
-grep -a "Prolog version:" "$results"/tester_versions.txt | $sed "s/Prolog/$prolog/"
-
-testsets=0
-output="$(find "$base" $level -name "tester.lgt" -or -name "tester.logtalk" | LC_ALL=C sort)"
-while read -r file && [ "$file" != "" ]; do
-	((testsets++))
-	run_tests "$file"
-done <<< "$output"
+drivers="$(find "$base" $level -type f -name "tester.lgt" -or -name "tester.logtalk" | LC_ALL=C sort)"
+testsets=$(find "$base" $level -type f -name "tester.lgt" -or -name "tester.logtalk" | wc -l | tr -d ' ')
+if [ "$output" == 'verbose' ] ; then
+	while read -r file && [ "$file" != "" ]; do
+		run_testset "$file"
+	done <<< "$drivers"
+else
+	counter=1
+	while read -r file && [ "$file" != "" ]; do
+		echo -ne "% running $testsets test sets: "
+		echo -ne "$counter"'\r'
+		run_testset "$file"
+		((counter++))
+	done <<< "$drivers"
+	echo
+fi
 
 cd "$results" || exit 1
 testsetskipped=$(cat -- *.results | grep -c 'tests skipped')
+testsetskipped=$((testsetskipped+$(cat -- *.results | grep -c '(not applicable)')))
 timeouts=$(cat -- *.errors | grep -c 'LOGTALK_TIMEOUT')
 crashes=$(cat -- *.errors | grep -c 'LOGTALK_CRASH')
 broken=$(cat -- *.errors | grep -c 'LOGTALK_BROKEN')
-testsetruns=$((testsets-timeouts-crashes-broken))
-skipped=$(cat -- *.results | grep -c ': skipped')
-passed=$(cat -- *.results | grep -c ': success')
-failed=$(cat -- *.results | grep -v 'test assertion' | grep -c ': failure')
+testsetruns=$((testsets-testsetskipped-timeouts-crashes-broken))
+
+skipped=0
+passed=0
+failed=0
+while read -r line ; do
+	skipped=$((skipped+$(cut -f 4 <<< "$line")))
+	passed=$((passed+$(cut -f 5 <<< "$line")))
+	failed=$((failed+$(cut -f 6 <<< "$line")))
+done < <(grep -s '^object' ./*.totals)
 total=$((skipped+passed+failed))
 
-echo "*******************************************************************************"
-echo "***** Compilation errors/warnings and failed unit tests"
-echo "***** (compilation errors/warnings might be expected depending on the test)"
-echo "*******************************************************************************"
-grep -s -a -A2 'syntax_error' -- *.results | $sed 's/.results//' | tee errors.all
-grep -s -a -A2 'syntax_error' -- *.errors | $sed 's/.errors//' | tee -a errors.all
-grep -s -a -h '!     ' -- *.errors | $sed 's/.errors//' | tee -a errors.all
-grep -s -a -h '!     ' -- *.results | $sed 's/.results//' | tee -a errors.all
-grep -s -a -h -F '*     ' -- *.errors | $sed 's/.errors//' | tee -a errors.all
-grep -s -a -h -F '*     ' -- *.results | $sed 's/.results//' | tee -a errors.all
-echo "*******************************************************************************"
-echo "***** Skipped"
-echo "*******************************************************************************"
-grep -s -a 'tests skipped' -- *.results | $sed 's/% tests skipped//' | $sed 's/.results://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
-echo "*******************************************************************************"
-echo "***** Broken"
-echo "*******************************************************************************"
-grep -s -a 'LOGTALK_BROKEN' -- *.errors | $sed 's/LOGTALK_BROKEN//' | $sed 's/.errors://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
-echo "*******************************************************************************"
-echo "***** Timeouts"
-echo "*******************************************************************************"
-grep -s -a 'LOGTALK_TIMEOUT' -- *.errors | $sed 's/LOGTALK_TIMEOUT//' | $sed 's/.errors://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
-echo "*******************************************************************************"
-echo "***** Crashes"
-echo "*******************************************************************************"
-grep -s -a 'LOGTALK_CRASH' -- *.errors | $sed 's/LOGTALK_CRASH//' | $sed 's/.errors://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
-echo "*******************************************************************************"
-echo "***** Skipped tests"
-echo "*******************************************************************************"
-grep -s -a ': skipped' -- *.results | $sed 's/: skipped//' | $sed 's/.results:% / - /' | $sed 's|__|/|g' | $sed "s|^$prefix||" | $sed "s|^% ||"
-echo "*******************************************************************************"
-echo "***** Failed tests"
-echo "*******************************************************************************"
-grep -s -a -v 'test assertion' -- *.results | grep ': failure' | $sed 's/: failure//' | $sed 's/.results:!     / - /' | $sed 's|__|/|g' | $sed "s|^$prefix||" | $sed "s|^!     ||"
-echo "*******************************************************************************"
-echo "***** $testsets test sets: $testsetruns completed, $testsetskipped skipped, $broken broken, $timeouts timeouts, $crashes crashes"
-echo "***** $total tests: $skipped skipped, $passed passed, $failed failed"
-echo "*******************************************************************************"
+if grep -q -s -a -h '^!' -- *.errors || grep -q -s -a -h '^!' -- *.results || grep -q -s -a -h '^\*' -- *.errors || grep -q -s -a -h '^\*' -- *.results ; then
+	echo "%"
+	echo "% Compilation errors/warnings and failed unit tests"
+	echo "% (compilation errors/warnings might be expected depending on the test)"
+	grep -s -a -h '^!' -- *.errors | $sed 's/.errors//' | tee -a errors.all
+	grep -s -a -h '^!' -- *.results | $sed 's/.results//' | tee -a errors.all
+	grep -s -a -h '^\*' -- *.errors | $sed 's/.errors//' | tee -a errors.all
+	grep -s -a -h '^\*' -- *.results | $sed 's/.results//' | tee -a errors.all
+fi
+if grep -q -s -a 'tests skipped' -- *.results || grep -q -s -a '(not applicable)' -- *.results ; then
+	echo "% Skipped"
+	grep -s -a 'tests skipped' -- *.results | $sed 's/% tests skipped//' | $sed 's/.results://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
+	grep -s -a '(not applicable)' -- *.results | $sed 's/(not applicable)//' | $sed 's/.results://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
+fi
+if grep -q -s -a 'LOGTALK_BROKEN' -- *.errors; then
+	echo "%"
+	echo "% Broken"
+	grep -s -a 'LOGTALK_BROKEN' -- *.errors | $sed 's/LOGTALK_BROKEN//' | $sed 's/.errors://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
+fi
+if grep -q -s -a 'LOGTALK_TIMEOUT' -- *.errors; then
+	echo "%"
+	echo "% Timeouts"
+	grep -s -a 'LOGTALK_TIMEOUT' -- *.errors | $sed 's/LOGTALK_TIMEOUT//' | $sed 's/.errors://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
+fi
+if grep -q -s -a 'LOGTALK_CRASH' -- *.errors; then
+	echo "%"
+	echo "% Crashes"
+	grep -s -a 'LOGTALK_CRASH' -- *.errors | $sed 's/LOGTALK_CRASH//' | $sed 's/.errors://' | $sed 's|__|/|g' | $sed "s|^$prefix||"
+fi
+if grep -s -q '^skipped' -- *.totals; then
+	echo "%"
+	echo "% Skipped tests"
+	for file in *.totals; do
+		if grep -s -q '^skipped' "$file"; then
+			path=$(grep -m 1 '^file' "$file" | cut -f 2 | $sed "s|^$prefix||")
+			grep '^skipped' "$file" | cut -f 2 | $sed "s|^|$path - |"
+		fi
+	done
+fi
+if grep -s -q '^failed' -- *.totals; then
+	echo "%"
+	echo "% Failed tests"
+	for file in *.totals; do
+		if grep -s -q '^failed' "$file"; then
+			path=$(grep -m 1 '^file' "$file" | cut -f 2 | $sed "s|^$prefix||")
+			grep '^failed' "$file" | cut -f 2 | $sed "s|^|$path - |"
+		fi
+	done
+fi
+echo "%"
+echo "% $testsets test sets: $testsetruns completed, $testsetskipped skipped, $broken broken, $timeouts timeouts, $crashes crashes"
+echo "% $total tests: $skipped skipped, $passed passed, $failed failed"
 
-end_date=$(eval date \"+%Y-%m-%d %H:%M:%S\")
-
-echo "***** Batch testing ended @ $end_date"
-echo '*******************************************************************************'
+if [ "$output" == 'verbose' ] ; then
+	end_date=$(eval date \"+%Y-%m-%d %H:%M:%S\")
+	echo "%"
+	echo "% Batch testing ended @ $end_date"
+fi
 
 if [ "$crashes" -gt 0 ] ; then
 	exit 7
